import {
  createMuiTheme,
  StylesProvider,
  Theme,
  ThemeProvider as MUIThemeProvider,
} from '@material-ui/core/styles';
import React, { useMemo } from 'react';
import { ThemeProvider as SCThemeProvider } from 'styled-components';
import lightTheme from '../styles/lightTheme';

export interface ThemeProviderProps {
  theme?: Theme;
}

const ThemeProvider: React.FC<ThemeProviderProps> = ({ theme: themeProp, children }) => {
  const theme = useMemo(() => (themeProp ? createMuiTheme(lightTheme, themeProp) : lightTheme), [
    themeProp,
  ]);
  return (
    <StylesProvider injectFirst>
      <MUIThemeProvider theme={theme}>
        <SCThemeProvider theme={theme}>{children}</SCThemeProvider>
      </MUIThemeProvider>
    </StylesProvider>
  );
};

export default ThemeProvider;
